@@ -16,6 +16,15 @@
 
 .splitNameParts <- function(pkgs)
 {
+    if (length(pkgs) == 0L) {
+        ans <- data.frame(pkgname=character(0),
+                          organism=factor(),
+                          provider=factor(),
+                          provider_version=character(0),
+                          masked=logical(0),
+                          stringsAsFactors=FALSE)
+        return(ans)
+    }
     ## Remove ".masked" suffix.
     pkgs2 <- pkgs
     is_masked <- substr(pkgs2, nchar(pkgs2) - 6L, nchar(pkgs2)) == ".masked"
@@ -23,7 +32,7 @@
     pkgs2[idx] <- substr(pkgs2[idx], 1L, nchar(pkgs2)[idx] - 7L)
 
     parts <- strsplit(pkgs2, ".", fixed=TRUE)
-    nparts <- elementLengths(parts)
+    nparts <- elementNROWS(parts)
     ## Some packages like BSgenome.Tgondii.ToxoDB.7.0 don't follow the rules
     ## and are made of more than 4 parts.
     has_more_than_4_parts <- which(nparts > 4L)
@@ -103,7 +112,7 @@ available.genomes <- function(splitNameParts=FALSE, type=getOption("pkgType"))
 {
     ## 1) Search installed packages.
     inst_pkgs <- installed.genomes(splitNameParts=TRUE)
-    inst_pkgs <- inst_pkgs[inst_pkgs[ , "masked"] == masked, ]
+    inst_pkgs <- inst_pkgs[inst_pkgs[ , "masked"] == masked, , drop=FALSE]
     idx <- which(genome == inst_pkgs[ , "provider_version"])
     if (length(idx) == 1L)
         return(inst_pkgs[idx , "pkgname"])
