@@ -33,6 +33,7 @@ BSgenome_datapkgs <- c(
   "BSgenome.Gaculeatus.UCSC.gasAcu1",
   "BSgenome.Ggallus.UCSC.galGal3",
   "BSgenome.Ggallus.UCSC.galGal4",
+  "BSgenome.Ggallus.UCSC.galGal5",
   "BSgenome.Hsapiens.UCSC.hg17",
   "BSgenome.Hsapiens.UCSC.hg18",
   "BSgenome.Hsapiens.UCSC.hg19",
@@ -42,11 +43,13 @@ BSgenome_datapkgs <- c(
   "BSgenome.Mfuro.UCSC.musFur1",
   "BSgenome.Mmulatta.UCSC.rheMac2",
   "BSgenome.Mmulatta.UCSC.rheMac3",
+  "BSgenome.Mmulatta.UCSC.rheMac8",
   "BSgenome.Mmusculus.UCSC.mm8",
   "BSgenome.Mmusculus.UCSC.mm9",
   "BSgenome.Mmusculus.UCSC.mm10",
   "BSgenome.Ptroglodytes.UCSC.panTro2",
   "BSgenome.Ptroglodytes.UCSC.panTro3",
+  "BSgenome.Ptroglodytes.UCSC.panTro5",
   "BSgenome.Rnorvegicus.UCSC.rn4",
   "BSgenome.Rnorvegicus.UCSC.rn5",
   "BSgenome.Rnorvegicus.UCSC.rn6",
